Added layer1 hold feature. Requires new mISDN and mISDNuser package from git.
[lcr.git] / mISDN.h
diff --git a/mISDN.h b/mISDN.h
index 13ca654..9907b9a 100644 (file)
--- a/mISDN.h
+++ b/mISDN.h
@@ -39,10 +39,12 @@ struct mISDNport {
        int ptp; /* if ptp is set, we keep track of l2link */
        int l1link; /* if l1 is available (only works with nt-mode) */
        int l2link; /* if l2 is available (at PTP we take this serious) */
+       int l1hold; /* set, if layer 1 should be holt */
        int l2hold; /* set, if layer 2 must be hold/checked */
        time_t l2establish; /* time until establishing after link failure */
        int use; /* counts the number of port that uses this port */
-       int ntmode; /* is TRUE if port is nt mode */
+       int ntmode; /* is TRUE if port is NT mode */
+       int tespecial; /* is TRUE if port uses special TE mode */
        int pri; /* is TRUE if port is a primary rate interface */
        int tones; /* TRUE if tones are sent outside connect state */
        int earlyb; /* TRUE if tones are received outside connect state */
@@ -51,6 +53,7 @@ struct mISDNport {
        class PmISDN *b_port[128]; /* bchannel assigned to port object */
        struct mqueue upqueue;
        int b_socket[128];
+       int b_mode[128]; /* B_MODE_* */
        int b_state[128]; /* statemachine, 0 = IDLE */
        double b_timer[128]; /* timer for state machine */
        int b_remote_id[128]; /* the socket currently exported (0=none) */
@@ -78,17 +81,16 @@ calls with no bchannel (call waiting, call on hold).
 /* mISDN none-object functions */
 int mISDN_initialize(void);
 void mISDN_deinitialize(void);
-void mISDN_port_info(void);
-struct mISDNport *mISDNport_open(int port, int ptp, int force_nt, int l2hold, struct interface *interface);
+struct mISDNport *mISDNport_open(int port, char *portname, int ptp, int force_nt, int te_special, int l1hold, int l2hold, struct interface *interface);
 void mISDNport_close_all(void);
 void mISDNport_close(struct mISDNport *mISDNport);
 void mISDN_port_reorder(void);
 int mISDN_handler(void);
 void enc_ie_cause_standalone(struct l3_msg *l3m, int location, int cause);
 int stack2manager(struct mISDNport *mISDNport, unsigned int cmd, unsigned int pid, struct l3_msg *l3m);
-void ph_control(struct mISDNport *mISDNport, class PmISDN *isdnport, unsigned int handle, unsigned int c1, unsigned int c2, char *trace_name, int trace_value);
-void ph_control_block(struct mISDNport *mISDNport, unsigned int handle, unsigned int c1, void *c2, int c2_len, char *trace_name, int trace_value);
-void chan_trace_header(struct mISDNport *mISDNport, class PmISDN *port, char *msgtext, int direction);
+void ph_control(struct mISDNport *mISDNport, class PmISDN *isdnport, unsigned int handle, unsigned int c1, unsigned int c2, const char *trace_name, int trace_value);
+void ph_control_block(struct mISDNport *mISDNport, unsigned int handle, unsigned int c1, void *c2, int c2_len, const char *trace_name, int trace_value);
+void chan_trace_header(struct mISDNport *mISDNport, class PmISDN *port, const char *msgtext, int direction);
 void l1l2l3_trace_header(struct mISDNport *mISDNport, class PmISDN *port, unsigned int prim, int direction);
 void bchannel_event(struct mISDNport *mISDNport, int i, int event);
 void message_bchannel_from_remote(class JoinRemote *joinremote, int type, unsigned int handle);
@@ -98,7 +100,7 @@ void message_bchannel_from_remote(class JoinRemote *joinremote, int type, unsign
 class PmISDN : public Port
 {
        public:
-       PmISDN(int type, struct mISDNport *mISDNport, char *portname, struct port_settings *settings, int channel, int exclusive);
+       PmISDN(int type, struct mISDNport *mISDNport, char *portname, struct port_settings *settings, int channel, int exclusive, int mode);
        ~PmISDN();
        void bchannel_receive(struct mISDNhead *hh, unsigned char *data, int len);
        int handler(void);
@@ -140,7 +142,7 @@ class PmISDN : public Port
        unsigned int p_m_crypt_listen_crc;
        void cryptman_listen_bch(unsigned char *p, int l);
 
-       void set_tone(char *dir, char *name);
+       void set_tone(const char *dir, const char *name);
        void set_echotest(int echotest);
 
        int p_m_portnum;                        /* used port number (1...n) */
@@ -150,12 +152,13 @@ class PmISDN : public Port
        int p_m_b_reserve;                      /* set if channel is reserved */
 //     long long p_m_jittercheck;              /* time of audio data */
 //     long long p_m_jitterdropped;            /* number of bytes dropped */
+       int p_m_b_mode;                         /* bchannel mode */
        int p_m_delete;                         /* true if obj. must del. */
        int p_m_hold;                           /* if port is on hold */
        unsigned int p_m_timeout;               /* timeout of timers */
        time_t p_m_timer;                       /* start of timer */
-       unsigned char p_m_remote_ref;           /* join to export bchannel to */
-       unsigned char p_m_remote_id;            /* sock to export bchannel to */
+       unsigned int p_m_remote_ref;            /* join to export bchannel to */
+       int p_m_remote_id;                      /* sock to export bchannel to */
 
        int seize_bchannel(int channel, int exclusive); /* requests / reserves / links bchannels, but does not open it! */
        void drop_bchannel(void);